This is a client library to interact with the Memex API.

Memex is an analytical database system that's unique in three ways: 
1. It integrates with and support high-throughput workloads for foundation models (LLMs)
2. It provides tooling for prompt development, testing, and logging
3. It provides an interface designed to browse multi-modal datasets alongside structured data


[Documentation](https://docs.memexdata.com)